@@ -19,7 +19,7 @@ class DynamoHelper(DynamoHelperBase):
 class DynamoTestHelper(DynamoHelperBase):
 
     def get_dynamo_db(self):
-        dynamo_alternate_endpoint = "http://localhost:8000"
+        dynamo_alternate_endpoint = "http://localhost:8008"
         dynamodb = boto3.resource('dynamodb', endpoint_url=dynamo_alternate_endpoint, region_name="us-west-1")
         return dynamodb
 
@@ -28,7 +28,7 @@ class EnvironmentControlledDynamoHelper(DynamoHelperBase):
 
     def __init__(self):
         self.dynamo_helper = DynamoHelper()
-        self.test_dynamo_helper = DynamoTestHelper
+        self.test_dynamo_helper = DynamoTestHelper()
 
     def get_dynamo_db(self):
         use_test_env_flag = os.environ.get('PROPERLY_USE_LOCAL_DYNAMO', None)
